
Give pci_find_bus a domain argument and move its declaration to <linux/pci.h>

diff -u drivers/pci/hotplug/acpiphp_glue.c drivers/pci/hotplug/acpiphp_glue.c
--- a/drivers/pci/hotplug/acpiphp_glue.c	27 Jun 2003 21:00:13 -0000
+++ b/drivers/pci/hotplug/acpiphp_glue.c	3 Jul 2003 11:46:01 -0000
@@ -385,7 +385,7 @@
 	bridge->seg = seg;
 	bridge->bus = bus;
 
-	bridge->pci_bus = pci_find_bus(bus);
+	bridge->pci_bus = pci_find_bus(seg, bus);
 
 	bridge->res_lock = SPIN_LOCK_UNLOCKED;
 
only in patch2:
--- a/include/linux/pci.h	2 Jul 2003 22:08:52 -0000	1.19
+++ b/include/linux/pci.h	3 Jul 2003 11:44:32 -0000
@@ -543,6 +543,7 @@ void pcibios_update_irq(struct pci_dev *
 
 /* Generic PCI functions used internally */
 
+extern struct pci_bus *pci_find_bus(int domain, int busnr);
 int pci_bus_exists(const struct list_head *list, int nr);
 struct pci_bus *pci_scan_bus_parented(struct device *parent, int bus, struct pci_ops *ops, void *sysdata);
 static inline struct pci_bus *pci_scan_bus(int bus, struct pci_ops *ops, void *sysdata)
only in patch2:
--- a/drivers/pci/hotplug/ibmphp_core.c	2 Jul 2003 22:08:22 -0000	1.3
+++ b/drivers/pci/hotplug/ibmphp_core.c	3 Jul 2003 11:46:23 -0000
@@ -774,7 +774,7 @@ static u8 bus_structure_fixup (u8 busno)
 	struct pci_dev *dev;
 	u16 l;
 
-	if (pci_find_bus(busno) || !(ibmphp_find_same_bus_num (busno)))
+	if (pci_find_bus(0, busno) || !(ibmphp_find_same_bus_num (busno)))
 		return 1;
 
 	bus = kmalloc (sizeof (*bus), GFP_KERNEL);
@@ -819,7 +819,7 @@ static int ibm_configure_device (struct 
 		func->dev = pci_find_slot (func->busno, PCI_DEVFN(func->device, func->function));
 
 	if (func->dev == NULL) {
-		struct pci_bus *bus = pci_find_bus(func->busno);
+		struct pci_bus *bus = pci_find_bus(0, func->busno);
 		if (!bus)
 			return 0;
 
@@ -1335,7 +1335,7 @@ static int __init ibmphp_init (void)
 		goto exit;
 	}
 
-	bus = pci_find_bus(0);
+	bus = pci_find_bus(0, 0);
 	if (!bus) {
 		err ("Can't find the root pci bus, can not continue\n");
 		rc = -ENODEV;
only in patch2:
--- a/drivers/pci/hotplug/cpci_hotplug_pci.c	14 Jun 2003 22:15:29 -0000	1.2
+++ b/drivers/pci/hotplug/cpci_hotplug_pci.c	3 Jul 2003 11:46:06 -0000
@@ -395,7 +395,7 @@ static int cpci_configure_bridge(struct 
 
 	/* Scan behind bridge */
 	n = pci_scan_bridge(bus, dev, max, 2);
-	child = pci_find_bus(max + 1);
+	child = pci_find_bus(0, max + 1);
 	if (!child)
 		return -ENODEV;
 	pci_proc_attach_bus(child);
only in patch2:
--- a/drivers/pci/search.c	23 Jun 2003 03:30:26 -0000	1.5
+++ b/drivers/pci/search.c	3 Jul 2003 11:43:13 -0000
@@ -30,22 +30,24 @@ pci_do_find_bus(struct pci_bus* bus, uns
 }
 
 /**
- * pci_find_bus - locate PCI bus from a given bus number
+ * pci_find_bus - locate PCI bus from a given domain and bus number
+ * @domain: number of PCI domain to search
  * @busnr: number of desired PCI bus
  *
- * Given a PCI bus number, the desired PCI bus is located in system
- * global list of PCI buses.  If the bus is found, a pointer to its
+ * Given a PCI bus number and domain number, the desired PCI bus is located
+ * in the global list of PCI buses.  If the bus is found, a pointer to its
  * data structure is returned.  If no bus is found, %NULL is returned.
  */
-struct pci_bus *
-pci_find_bus(unsigned char busnr)
+struct pci_bus * pci_find_bus(int domain, int busnr)
 {
-	struct pci_bus* bus = NULL;
-	struct pci_bus* tmp_bus;
+	struct pci_bus *bus = NULL;
+	struct pci_bus *tmp_bus;
 
 	while ((bus = pci_find_next_bus(bus)) != NULL)  {
+		if (pci_domain_nr(bus) != domain)
+			continue;
 		tmp_bus = pci_do_find_bus(bus, busnr);
-		if(tmp_bus)
+		if (tmp_bus)
 			return tmp_bus;
 	}
 	return NULL;
only in patch2:
--- a/drivers/pci/pci.h	23 Jun 2003 03:30:26 -0000	1.5
+++ b/drivers/pci/pci.h	3 Jul 2003 11:43:34 -0000
@@ -29,7 +29,6 @@ extern int pci_remove_device_safe(struct
 extern unsigned char pci_max_busnr(void);
 extern unsigned char pci_bus_max_busnr(struct pci_bus *bus);
 extern int pci_bus_find_capability (struct pci_bus *bus, unsigned int devfn, int cap);
-extern struct pci_bus *pci_find_bus(unsigned char busnr);
 
 struct pci_dev_wrapped {
 	struct pci_dev	*dev;
